@@ -16,9 +16,17 @@ from .persistent_widgets import (
     PersistentCheckBox,
     PersistentLineEdit,
     PersistentTextEdit,
+    PersistentPlainTextEdit,
     PersistentListWidget,
     PersistentTreeWidget,
     PersistentComboBox,
     PersistentCheckableAction,
 )
-from .persistent_tab_widget import PersistentTabWidget
\ No newline at end of file
+from .persistent_tab_widget import PersistentTabWidget
+from .toggle import (
+    Toggle, 
+    AnimatedToggle, 
+    PersistentToggle, 
+    PersistentAnimatedToggle
+)
+from .toolbar import BaseToolbar, SettingsToolbar
\ No newline at end of file
